@@ -13,6 +13,20 @@ async def log_async(message, level: DebugLevel = DebugLevel.INFO):
     await handler.log(message, level)
 
 
+def useUser(handler: AssignHandler = None, strict=False):
+    handler = handler or assign_handler_context.get()
+    assert handler is not None, "You cannot get the User if you are not running inside a (functional Actor)"
+    if strict: assert handler.message.meta.token.user is not None, "No user provided by (nested) Assignation"
+    return handler.message.meta.token.user
+
+
+def useApp(handler: AssignHandler = None, strict=False):
+    handler = handler or assign_handler_context.get()
+    assert handler is not None, "You cannot get the App if you are not running inside a (functional Actor)"
+    if strict: assert handler.message.meta.token.user is not None, "No user provided by (nested) Assignation"
+    return handler.message.meta.token.app
+
+
 def log(message: str, level: DebugLevel = DebugLevel.INFO):
     """ Logs a message
 
