@@ -1,3 +1,6 @@
+import asyncio
+from typing import Any
+from bergen.contracts.reservation import Reservation
 from bergen.contracts.interaction import Interaction
 
 from bergen.monitor.monitor import Monitor
@@ -76,6 +79,10 @@ class NodeExtender(AssignationUIMixin):
         return string
 
 
+    def __call__(self, *args: Any, **kwds: Any) -> Any:
+        return super().__call__(*args, **kwds)
+
+
     def __rich__(self):
         my_table = Table(title=f"Node: {self.name}", show_header=False)
 
